==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/GridColumnSortOptionsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { GridColumnOptionsSimpleSectionBaseDescriptionMetadata } from "./GridColumnOptionsSimpleSectionBaseDescriptionMetadata";
import { GridColumnSortOptionsDescription } from "./GridColumnSortOptionsDescription";
/**
 * @hidden
 */
export let GridColumnSortOptionsDescriptionMetadata = /*@__PURE__*/ (() => {
    class GridColumnSortOptionsDescriptionMetadata extends Base {
        static b(a) {
            if (GridColumnSortOptionsDescriptionMetadata.a == null) {
                GridColumnSortOptionsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                GridColumnSortOptionsDescriptionMetadata.c(GridColumnSortOptionsDescriptionMetadata.a);
            }
            if (a.k(GridColumnSortOptionsDescriptionMetadata.a)) {
                return;
            }
            a.ab(GridColumnSortOptionsDescriptionMetadata.a);
        }
        static c(a) {
            GridColumnOptionsSimpleSectionBaseDescriptionMetadata.c(a);
            a.item("AscendingCaption", "String");
            a.item("DescendingCaption", "String");
            a.item("SortDirection", "ExportedType:string:ColumnSortDirection");
            a.item("SortDirection@names", "None;Ascending;Descending");
        }
        static d(a) {
            GridColumnSortOptionsDescriptionMetadata.b(a);
            a.ad("GridColumnSortOptions", () => new GridColumnSortOptionsDescription());
            a.ac("GridColumnSortOptions", GridColumnSortOptionsDescriptionMetadata.a);
        }
    }
    GridColumnSortOptionsDescriptionMetadata.$t = markType(GridColumnSortOptionsDescriptionMetadata, 'GridColumnSortOptionsDescriptionMetadata');
    GridColumnSortOptionsDescriptionMetadata.a = null;
    return GridColumnSortOptionsDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/GridColumnSortOptionsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { GridColumnOptionsSimpleSectionBaseDescriptionMetadata } from "./GridColumnOptionsSimpleSectionBaseDescriptionMetadata";
import { GridColumnSortOptionsDescription } from "./GridColumnSortOptionsDescription";
/**
 * @hidden
 */
export let GridColumnSortOptionsDescriptionMetadata = /*@__PURE__*/ (() => {
    class GridColumnSortOptionsDescriptionMetadata extends Base {
        static b(a) {
            if (GridColumnSortOptionsDescriptionMetadata.a == null) {
                GridColumnSortOptionsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                GridColumnSortOptionsDescriptionMetadata.c(GridColumnSortOptionsDescriptionMetadata.a);
            }
            if (a.k(GridColumnSortOptionsDescriptionMetadata.a)) {
                return;
            }
            a.ac(GridColumnSortOptionsDescriptionMetadata.a);
        }
        static c(a) {
            GridColumnOptionsSimpleSectionBaseDescriptionMetadata.c(a);
            a.item("AscendingCaption", "String");
            a.item("DescendingCaption", "String");
            a.item("SortDirection", "ExportedType:string:ColumnSortDirection");
            a.item("SortDirection@names", "None;Ascending;Descending");
        }
        static d(a) {
            GridColumnSortOptionsDescriptionMetadata.b(a);
            a.ae("GridColumnSortOptions", () => new GridColumnSortOptionsDescription());
            a.ad("GridColumnSortOptions", GridColumnSortOptionsDescriptionMetadata.a);
        }
    }
    GridColumnSortOptionsDescriptionMetadata.$t = markType(GridColumnSortOptionsDescriptionMetadata, 'GridColumnSortOptionsDescriptionMetadata');
    GridColumnSortOptionsDescriptionMetadata.a = null;
    return GridColumnSortOptionsDescriptionMetadata;
})();
